
/******************** (C) COPYRIGHT 2013 STMicroelectronics ********************
* File Name          : LIS3MDL_MAG_driver.c
* Author             : MSH Application Team
* Version            : v1.10
* Date               : 12/11/2013 
* Description        : LIS3MDL MAG driver source file
*                      
* HISTORY:
* Date:   12/11/2013            
* Modification: Initial Revision                
* Author:	Platform Independent Driver Generator v0.03
* Reviewed by: Alberto Zancanato
*-------------------------------------------------------------------------------
*
*
********************************************************************************
* THE PRESENT FIRMWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
* WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE TIME.
* AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY DIRECT,
* INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING FROM THE
* CONTENT OF SUCH FIRMWARE AND/OR THE USE MADE BY CUSTOMERS OF THE CODING
* INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
*
* THIS SOFTWARE IS SPECIFICALLY DESIGNED FOR EXCLUSIVE USE WITH ST PARTS.
*
*******************************************************************************/

/* Includes ------------------------------------------------------------------*/
#include "lis3mdl.h"

/* Private typedef -----------------------------------------------------------*/

/* Private define ------------------------------------------------------------*/

/* Private macro -------------------------------------------------------------*/

/* Private variables ---------------------------------------------------------*/

/* Private functions ---------------------------------------------------------*/

/*******************************************************************************
* Function Name		: LIS3MDL_MAG_ReadReg
* Description		: Generic Reading function. It must be fullfilled with either
*					: I2C or SPI reading functions					
* Input				: Register Address
* Output			: Data REad
* Return			: None
*******************************************************************************/
u8_t LIS3MDL_MAG_ReadReg(ATMO_DriverInstanceHandle_t i2cInstance, uint8_t i2cAddr, u8_t Reg, u8_t* Data) 
{

  ATMO_I2C_MasterRead(i2cInstance, i2cAddr, &Reg, 1, Data, 1, 0);

  return LIS3MDL_SUCCESS;
  
  //To be completed with either I2c or SPI reading function
  //i.e.: *Data = SPI_Mems_Read_Reg( Reg );
/*  if(!I2C_BufferRead(Data, LIS3MDL_MAG_I2C_ADDRESS, Reg, 1))  //[Example]
	return LIS3MDL_ERROR;                                                        //[Example]
  else                                                                        //[Example]
	return LIS3MDL_SUCCESS;  */                                                    //[Example]
}

/*******************************************************************************
* Function Name		: LIS3MDL_MAG_WriteReg
* Description		: Generic Writing function. It must be fullfilled with either
*					: I2C or SPI writing function
* Input				: Register Address, Data to be written
* Output			: None
* Return			: None
*******************************************************************************/
u8_t LIS3MDL_MAG_WriteReg(ATMO_DriverInstanceHandle_t i2cInstance, uint8_t i2cAddr, u8_t Reg, u8_t Data) 
{
  ATMO_I2C_MasterWrite(i2cInstance, i2cAddr, &Reg, 1, &Data, 1, 0);
  
  return LIS3MDL_SUCCESS;
  
  //To be completed with either I2c or SPI writing function
  //i.e.: SPI_Mems_Write_Reg(Reg, Data);
/*  I2C_ByteWrite(&Data,  LIS3MDL_MAG_I2C_ADDRESS,  Reg);       //[Example]
  return LIS3MDL_SUCCESS;    */                                                    //[Example]
}

/*******************************************************************************
* Function Name		: SwapHighLowByte
* Description		: Swap High/low byte in multiple byte values 
*                     It works with minimum 2 byte for every dimension.
*                     Example x,y,z with 2 byte for every dimension
*
* Input				: bufferToSwap -> buffer to swap 
*                     numberOfByte -> the buffer length in byte
*                     dimension -> number of dimension 
*
* Output			: bufferToSwap -> buffer swapped 
* Return			: None
*******************************************************************************/
void LIS3MDL_MAG_SwapHighLowByte(u8_t *bufferToSwap, u8_t numberOfByte, u8_t dimension)
{

  u8_t numberOfByteForDimension, i, j;
  u8_t tempValue[10];
  
  numberOfByteForDimension=numberOfByte/dimension;
    
  for (i=0; i<dimension;i++ )
  {
	for (j=0; j<numberOfByteForDimension;j++ )
		tempValue[j]=bufferToSwap[j+i*numberOfByteForDimension];
	for (j=0; j<numberOfByteForDimension;j++ )
		*(bufferToSwap+i*(numberOfByteForDimension)+j)=*(tempValue+(numberOfByteForDimension-1)-j);
  } 
}

/* Exported functions ---------------------------------------------------------*/

/*******************************************************************************
* Function Name  : LIS3MDL_MAG_R_WHO_AM_I_
* Description    : Read WHO_AM_I_BIT
* Input          : Pointer to u8_t
* Output         : Status of WHO_AM_I_BIT 
* Return         : Status [LIS3MDL_ERROR, LIS3MDL_SUCCESS]
*******************************************************************************/

lis3mdl_status_t LIS3MDL_MAG_R_WHO_AM_I_(ATMO_DriverInstanceHandle_t i2cInstance, uint8_t i2cAddr, u8_t *value)
{
 if( !LIS3MDL_MAG_ReadReg(i2cInstance, i2cAddr, LIS3MDL_MAG_WHO_AM_I_REG, (u8_t *)value) )
    return LIS3MDL_ERROR;

  *value &= LIS3MDL_MAG_WHO_AM_I_BIT_MASK; //coerce	
  *value = *value >> LIS3MDL_MAG_WHO_AM_I_BIT_POSITION; //mask	

  return LIS3MDL_SUCCESS;
}
/*******************************************************************************
* Function Name  : LIS3MDL_MAG_W_SelfTest
* Description    : Write ST
* Input          : LIS3MDL_MAG_ST_t
* Output         : None
* Return         : Status [LIS3MDL_ERROR, LIS3MDL_SUCCESS]
*******************************************************************************/
lis3mdl_status_t  LIS3MDL_MAG_W_SelfTest(ATMO_DriverInstanceHandle_t i2cInstance, uint8_t i2cAddr, LIS3MDL_MAG_ST_t newValue)
{
  u8_t value;

  if( !LIS3MDL_MAG_ReadReg(i2cInstance, i2cAddr, LIS3MDL_MAG_CTRL_REG1, &value) )
    return LIS3MDL_ERROR;

  value &= ~LIS3MDL_MAG_ST_MASK; 
  value |= newValue;
  
  if( !LIS3MDL_MAG_WriteReg(i2cInstance, i2cAddr, LIS3MDL_MAG_CTRL_REG1, value) )
    return LIS3MDL_ERROR;

  return LIS3MDL_SUCCESS;
}

/*******************************************************************************
* Function Name  : LIS3MDL_MAG_R_SelfTest
* Description    : Read ST
* Input          : Pointer to LIS3MDL_MAG_ST_t
* Output         : Status of ST see LIS3MDL_MAG_ST_t
* Return         : Status [LIS3MDL_ERROR, LIS3MDL_SUCCESS]
*******************************************************************************/

lis3mdl_status_t LIS3MDL_MAG_R_SelfTest(ATMO_DriverInstanceHandle_t i2cInstance, uint8_t i2cAddr, LIS3MDL_MAG_ST_t *value)
{
 if( !LIS3MDL_MAG_ReadReg(i2cInstance, i2cAddr, LIS3MDL_MAG_CTRL_REG1, (u8_t *)value) )
    return LIS3MDL_ERROR;

  *(int*)value &= LIS3MDL_MAG_ST_MASK; //mask

  return LIS3MDL_SUCCESS;
}
/*******************************************************************************
* Function Name  : LIS3MDL_MAG_W_OutputDataRate
* Description    : Write DO
* Input          : LIS3MDL_MAG_DO_t
* Output         : None
* Return         : Status [LIS3MDL_ERROR, LIS3MDL_SUCCESS]
*******************************************************************************/
lis3mdl_status_t  LIS3MDL_MAG_W_OutputDataRate(ATMO_DriverInstanceHandle_t i2cInstance, uint8_t i2cAddr, LIS3MDL_MAG_DO_t newValue)
{
  u8_t value;

  if( !LIS3MDL_MAG_ReadReg(i2cInstance, i2cAddr, LIS3MDL_MAG_CTRL_REG1, &value) )
    return LIS3MDL_ERROR;

  value &= ~LIS3MDL_MAG_DO_MASK; 
  value |= newValue;
  
  if( !LIS3MDL_MAG_WriteReg(i2cInstance, i2cAddr, LIS3MDL_MAG_CTRL_REG1, value) )
    return LIS3MDL_ERROR;

  return LIS3MDL_SUCCESS;
}

/*******************************************************************************
* Function Name  : LIS3MDL_MAG_R_OutputDataRate
* Description    : Read DO
* Input          : Pointer to LIS3MDL_MAG_DO_t
* Output         : Status of DO see LIS3MDL_MAG_DO_t
* Return         : Status [LIS3MDL_ERROR, LIS3MDL_SUCCESS]
*******************************************************************************/

lis3mdl_status_t LIS3MDL_MAG_R_OutputDataRate(ATMO_DriverInstanceHandle_t i2cInstance, uint8_t i2cAddr, LIS3MDL_MAG_DO_t *value)
{
 if( !LIS3MDL_MAG_ReadReg(i2cInstance, i2cAddr, LIS3MDL_MAG_CTRL_REG1, (u8_t *)value) )
    return LIS3MDL_ERROR;

  *(int*)value &= LIS3MDL_MAG_DO_MASK; //mask

  return LIS3MDL_SUCCESS;
}
/*******************************************************************************
* Function Name  : LIS3MDL_MAG_W_OperatingModeXY
* Description    : Write OM
* Input          : LIS3MDL_MAG_OM_t
* Output         : None
* Return         : Status [LIS3MDL_ERROR, LIS3MDL_SUCCESS]
*******************************************************************************/
lis3mdl_status_t  LIS3MDL_MAG_W_OperatingModeXY(ATMO_DriverInstanceHandle_t i2cInstance, uint8_t i2cAddr, LIS3MDL_MAG_OM_t newValue)
{
  u8_t value;

  if( !LIS3MDL_MAG_ReadReg(i2cInstance, i2cAddr, LIS3MDL_MAG_CTRL_REG1, &value) )
    return LIS3MDL_ERROR;

  value &= ~LIS3MDL_MAG_OM_MASK; 
  value |= newValue;
  
  if( !LIS3MDL_MAG_WriteReg(i2cInstance, i2cAddr, LIS3MDL_MAG_CTRL_REG1, value) )
    return LIS3MDL_ERROR;

  return LIS3MDL_SUCCESS;
}

/*******************************************************************************
* Function Name  : LIS3MDL_MAG_R_OperatingModeXY
* Description    : Read OM
* Input          : Pointer to LIS3MDL_MAG_OM_t
* Output         : Status of OM see LIS3MDL_MAG_OM_t
* Return         : Status [LIS3MDL_ERROR, LIS3MDL_SUCCESS]
*******************************************************************************/

lis3mdl_status_t LIS3MDL_MAG_R_OperatingModeXY(ATMO_DriverInstanceHandle_t i2cInstance, uint8_t i2cAddr, LIS3MDL_MAG_OM_t *value)
{
 if( !LIS3MDL_MAG_ReadReg(i2cInstance, i2cAddr, LIS3MDL_MAG_CTRL_REG1, (u8_t *)value) )
    return LIS3MDL_ERROR;

  *(int*)value &= LIS3MDL_MAG_OM_MASK; //mask

  return LIS3MDL_SUCCESS;
}
/*******************************************************************************
* Function Name  : LIS3MDL_MAG_W_TemperatureSensor
* Description    : Write TEMP_EN
* Input          : LIS3MDL_MAG_TEMP_EN_t
* Output         : None
* Return         : Status [LIS3MDL_ERROR, LIS3MDL_SUCCESS]
*******************************************************************************/
lis3mdl_status_t  LIS3MDL_MAG_W_TemperatureSensor(ATMO_DriverInstanceHandle_t i2cInstance, uint8_t i2cAddr, LIS3MDL_MAG_TEMP_EN_t newValue)
{
  u8_t value;

  if( !LIS3MDL_MAG_ReadReg(i2cInstance, i2cAddr, LIS3MDL_MAG_CTRL_REG1, &value) )
    return LIS3MDL_ERROR;

  value &= ~LIS3MDL_MAG_TEMP_EN_MASK; 
  value |= newValue;
  
  if( !LIS3MDL_MAG_WriteReg(i2cInstance, i2cAddr, LIS3MDL_MAG_CTRL_REG1, value) )
    return LIS3MDL_ERROR;

  return LIS3MDL_SUCCESS;
}

/*******************************************************************************
* Function Name  : LIS3MDL_MAG_R_TemperatureSensor
* Description    : Read TEMP_EN
* Input          : Pointer to LIS3MDL_MAG_TEMP_EN_t
* Output         : Status of TEMP_EN see LIS3MDL_MAG_TEMP_EN_t
* Return         : Status [LIS3MDL_ERROR, LIS3MDL_SUCCESS]
*******************************************************************************/

lis3mdl_status_t LIS3MDL_MAG_R_TemperatureSensor(ATMO_DriverInstanceHandle_t i2cInstance, uint8_t i2cAddr, LIS3MDL_MAG_TEMP_EN_t *value)
{
 if( !LIS3MDL_MAG_ReadReg(i2cInstance, i2cAddr, LIS3MDL_MAG_CTRL_REG1, (u8_t *)value) )
    return LIS3MDL_ERROR;

  *(int*)value &= LIS3MDL_MAG_TEMP_EN_MASK; //mask

  return LIS3MDL_SUCCESS;
}
/*******************************************************************************
* Function Name  : LIS3MDL_MAG_W_SoftRST
* Description    : Write SOFT_RST
* Input          : LIS3MDL_MAG_SOFT_RST_t
* Output         : None
* Return         : Status [LIS3MDL_ERROR, LIS3MDL_SUCCESS]
*******************************************************************************/
lis3mdl_status_t  LIS3MDL_MAG_W_SoftRST(ATMO_DriverInstanceHandle_t i2cInstance, uint8_t i2cAddr, LIS3MDL_MAG_SOFT_RST_t newValue)
{
  u8_t value;

  if( !LIS3MDL_MAG_ReadReg(i2cInstance, i2cAddr, LIS3MDL_MAG_CTRL_REG2, &value) )
    return LIS3MDL_ERROR;

  value &= ~LIS3MDL_MAG_SOFT_RST_MASK; 
  value |= newValue;
  
  if( !LIS3MDL_MAG_WriteReg(i2cInstance, i2cAddr, LIS3MDL_MAG_CTRL_REG2, value) )
    return LIS3MDL_ERROR;

  return LIS3MDL_SUCCESS;
}

/*******************************************************************************
* Function Name  : LIS3MDL_MAG_R_SoftRST
* Description    : Read SOFT_RST
* Input          : Pointer to LIS3MDL_MAG_SOFT_RST_t
* Output         : Status of SOFT_RST see LIS3MDL_MAG_SOFT_RST_t
* Return         : Status [LIS3MDL_ERROR, LIS3MDL_SUCCESS]
*******************************************************************************/

lis3mdl_status_t LIS3MDL_MAG_R_SoftRST(ATMO_DriverInstanceHandle_t i2cInstance, uint8_t i2cAddr, LIS3MDL_MAG_SOFT_RST_t *value)
{
 if( !LIS3MDL_MAG_ReadReg(i2cInstance, i2cAddr, LIS3MDL_MAG_CTRL_REG2, (u8_t *)value) )
    return LIS3MDL_ERROR;

  *(int*)value &= LIS3MDL_MAG_SOFT_RST_MASK; //mask

  return LIS3MDL_SUCCESS;
}
/*******************************************************************************
* Function Name  : LIS3MDL_MAG_W_Reboot
* Description    : Write REBOOT
* Input          : LIS3MDL_MAG_REBOOT_t
* Output         : None
* Return         : Status [LIS3MDL_ERROR, LIS3MDL_SUCCESS]
*******************************************************************************/
lis3mdl_status_t  LIS3MDL_MAG_W_Reboot(ATMO_DriverInstanceHandle_t i2cInstance, uint8_t i2cAddr, LIS3MDL_MAG_REBOOT_t newValue)
{
  u8_t value;

  if( !LIS3MDL_MAG_ReadReg(i2cInstance, i2cAddr, LIS3MDL_MAG_CTRL_REG2, &value) )
    return LIS3MDL_ERROR;

  value &= ~LIS3MDL_MAG_REBOOT_MASK; 
  value |= newValue;
  
  if( !LIS3MDL_MAG_WriteReg(i2cInstance, i2cAddr, LIS3MDL_MAG_CTRL_REG2, value) )
    return LIS3MDL_ERROR;

  return LIS3MDL_SUCCESS;
}

/*******************************************************************************
* Function Name  : LIS3MDL_MAG_R_Reboot
* Description    : Read REBOOT
* Input          : Pointer to LIS3MDL_MAG_REBOOT_t
* Output         : Status of REBOOT see LIS3MDL_MAG_REBOOT_t
* Return         : Status [LIS3MDL_ERROR, LIS3MDL_SUCCESS]
*******************************************************************************/

lis3mdl_status_t LIS3MDL_MAG_R_Reboot(ATMO_DriverInstanceHandle_t i2cInstance, uint8_t i2cAddr, LIS3MDL_MAG_REBOOT_t *value)
{
 if( !LIS3MDL_MAG_ReadReg(i2cInstance, i2cAddr, LIS3MDL_MAG_CTRL_REG2, (u8_t *)value) )
    return LIS3MDL_ERROR;

  *(int*)value &= LIS3MDL_MAG_REBOOT_MASK; //mask

  return LIS3MDL_SUCCESS;
}
/*******************************************************************************
* Function Name  : LIS3MDL_MAG_W_FullScale
* Description    : Write FS
* Input          : LIS3MDL_MAG_FS_t
* Output         : None
* Return         : Status [LIS3MDL_ERROR, LIS3MDL_SUCCESS]
*******************************************************************************/
lis3mdl_status_t  LIS3MDL_MAG_W_FullScale(ATMO_DriverInstanceHandle_t i2cInstance, uint8_t i2cAddr, LIS3MDL_MAG_FS_t newValue)
{
  u8_t value;

  if( !LIS3MDL_MAG_ReadReg(i2cInstance, i2cAddr, LIS3MDL_MAG_CTRL_REG2, &value) )
    return LIS3MDL_ERROR;

  value &= ~LIS3MDL_MAG_FS_MASK; 
  value |= newValue;
  
  if( !LIS3MDL_MAG_WriteReg(i2cInstance, i2cAddr, LIS3MDL_MAG_CTRL_REG2, value) )
    return LIS3MDL_ERROR;

  return LIS3MDL_SUCCESS;
}

/*******************************************************************************
* Function Name  : LIS3MDL_MAG_R_FullScale
* Description    : Read FS
* Input          : Pointer to LIS3MDL_MAG_FS_t
* Output         : Status of FS see LIS3MDL_MAG_FS_t
* Return         : Status [LIS3MDL_ERROR, LIS3MDL_SUCCESS]
*******************************************************************************/

lis3mdl_status_t LIS3MDL_MAG_R_FullScale(ATMO_DriverInstanceHandle_t i2cInstance, uint8_t i2cAddr, LIS3MDL_MAG_FS_t *value)
{
 if( !LIS3MDL_MAG_ReadReg(i2cInstance, i2cAddr, LIS3MDL_MAG_CTRL_REG2, (u8_t *)value) )
    return LIS3MDL_ERROR;

  *(int*)value &= LIS3MDL_MAG_FS_MASK; //mask

  return LIS3MDL_SUCCESS;
}
/*******************************************************************************
* Function Name  : LIS3MDL_MAG_W_SystemOperatingMode
* Description    : Write MD
* Input          : LIS3MDL_MAG_MD_t
* Output         : None
* Return         : Status [LIS3MDL_ERROR, LIS3MDL_SUCCESS]
*******************************************************************************/
lis3mdl_status_t  LIS3MDL_MAG_W_SystemOperatingMode(ATMO_DriverInstanceHandle_t i2cInstance, uint8_t i2cAddr, LIS3MDL_MAG_MD_t newValue)
{
  u8_t value;

  if( !LIS3MDL_MAG_ReadReg(i2cInstance, i2cAddr, LIS3MDL_MAG_CTRL_REG3, &value) )
    return LIS3MDL_ERROR;

  value &= ~LIS3MDL_MAG_MD_MASK; 
  value |= newValue;
  
  if( !LIS3MDL_MAG_WriteReg(i2cInstance, i2cAddr, LIS3MDL_MAG_CTRL_REG3, value) )
    return LIS3MDL_ERROR;

  return LIS3MDL_SUCCESS;
}

/*******************************************************************************
* Function Name  : LIS3MDL_MAG_R_SystemOperatingMode
* Description    : Read MD
* Input          : Pointer to LIS3MDL_MAG_MD_t
* Output         : Status of MD see LIS3MDL_MAG_MD_t
* Return         : Status [LIS3MDL_ERROR, LIS3MDL_SUCCESS]
*******************************************************************************/

lis3mdl_status_t LIS3MDL_MAG_R_SystemOperatingMode(ATMO_DriverInstanceHandle_t i2cInstance, uint8_t i2cAddr, LIS3MDL_MAG_MD_t *value)
{
 if( !LIS3MDL_MAG_ReadReg(i2cInstance, i2cAddr, LIS3MDL_MAG_CTRL_REG3, (u8_t *)value) )
    return LIS3MDL_ERROR;

  *(int*)value &= LIS3MDL_MAG_MD_MASK; //mask

  return LIS3MDL_SUCCESS;
}
/*******************************************************************************
* Function Name  : LIS3MDL_MAG_W_SerialInterfaceMode
* Description    : Write SIM
* Input          : LIS3MDL_MAG_SIM_t
* Output         : None
* Return         : Status [LIS3MDL_ERROR, LIS3MDL_SUCCESS]
*******************************************************************************/
lis3mdl_status_t  LIS3MDL_MAG_W_SerialInterfaceMode(ATMO_DriverInstanceHandle_t i2cInstance, uint8_t i2cAddr, LIS3MDL_MAG_SIM_t newValue)
{
  u8_t value;

  if( !LIS3MDL_MAG_ReadReg(i2cInstance, i2cAddr, LIS3MDL_MAG_CTRL_REG3, &value) )
    return LIS3MDL_ERROR;

  value &= ~LIS3MDL_MAG_SIM_MASK; 
  value |= newValue;
  
  if( !LIS3MDL_MAG_WriteReg(i2cInstance, i2cAddr, LIS3MDL_MAG_CTRL_REG3, value) )
    return LIS3MDL_ERROR;

  return LIS3MDL_SUCCESS;
}

/*******************************************************************************
* Function Name  : LIS3MDL_MAG_R_SerialInterfaceMode
* Description    : Read SIM
* Input          : Pointer to LIS3MDL_MAG_SIM_t
* Output         : Status of SIM see LIS3MDL_MAG_SIM_t
* Return         : Status [LIS3MDL_ERROR, LIS3MDL_SUCCESS]
*******************************************************************************/

lis3mdl_status_t LIS3MDL_MAG_R_SerialInterfaceMode(ATMO_DriverInstanceHandle_t i2cInstance, uint8_t i2cAddr, LIS3MDL_MAG_SIM_t *value)
{
 if( !LIS3MDL_MAG_ReadReg(i2cInstance, i2cAddr, LIS3MDL_MAG_CTRL_REG3, (u8_t *)value) )
    return LIS3MDL_ERROR;

  *(int*)value &= LIS3MDL_MAG_SIM_MASK; //mask

  return LIS3MDL_SUCCESS;
}
/*******************************************************************************
* Function Name  : LIS3MDL_MAG_W_FastLowPowerXYZ
* Description    : Write LP
* Input          : LIS3MDL_MAG_LP_t
* Output         : None
* Return         : Status [LIS3MDL_ERROR, LIS3MDL_SUCCESS]
*******************************************************************************/
lis3mdl_status_t  LIS3MDL_MAG_W_FastLowPowerXYZ(ATMO_DriverInstanceHandle_t i2cInstance, uint8_t i2cAddr, LIS3MDL_MAG_LP_t newValue)
{
  u8_t value;

  if( !LIS3MDL_MAG_ReadReg(i2cInstance, i2cAddr, LIS3MDL_MAG_CTRL_REG3, &value) )
    return LIS3MDL_ERROR;

  value &= ~LIS3MDL_MAG_LP_MASK; 
  value |= newValue;
  
  if( !LIS3MDL_MAG_WriteReg(i2cInstance, i2cAddr, LIS3MDL_MAG_CTRL_REG3, value) )
    return LIS3MDL_ERROR;

  return LIS3MDL_SUCCESS;
}

/*******************************************************************************
* Function Name  : LIS3MDL_MAG_R_FastLowPowerXYZ
* Description    : Read LP
* Input          : Pointer to LIS3MDL_MAG_LP_t
* Output         : Status of LP see LIS3MDL_MAG_LP_t
* Return         : Status [LIS3MDL_ERROR, LIS3MDL_SUCCESS]
*******************************************************************************/

lis3mdl_status_t LIS3MDL_MAG_R_FastLowPowerXYZ(ATMO_DriverInstanceHandle_t i2cInstance, uint8_t i2cAddr, LIS3MDL_MAG_LP_t *value)
{
 if( !LIS3MDL_MAG_ReadReg(i2cInstance, i2cAddr, LIS3MDL_MAG_CTRL_REG3, (u8_t *)value) )
    return LIS3MDL_ERROR;

  *(int*)value &= LIS3MDL_MAG_LP_MASK; //mask

  return LIS3MDL_SUCCESS;
}
/*******************************************************************************
* Function Name  : LIS3MDL_MAG_W_LittleBigEndianInversion
* Description    : Write BLE
* Input          : LIS3MDL_MAG_BLE_t
* Output         : None
* Return         : Status [LIS3MDL_ERROR, LIS3MDL_SUCCESS]
*******************************************************************************/
lis3mdl_status_t  LIS3MDL_MAG_W_LittleBigEndianInversion(ATMO_DriverInstanceHandle_t i2cInstance, uint8_t i2cAddr, LIS3MDL_MAG_BLE_t newValue)
{
  u8_t value;

  if( !LIS3MDL_MAG_ReadReg(i2cInstance, i2cAddr, LIS3MDL_MAG_CTRL_REG4, &value) )
    return LIS3MDL_ERROR;

  value &= ~LIS3MDL_MAG_BLE_MASK; 
  value |= newValue;
  
  if( !LIS3MDL_MAG_WriteReg(i2cInstance, i2cAddr, LIS3MDL_MAG_CTRL_REG4, value) )
    return LIS3MDL_ERROR;

  return LIS3MDL_SUCCESS;
}

/*******************************************************************************
* Function Name  : LIS3MDL_MAG_R_LittleBigEndianInversion
* Description    : Read BLE
* Input          : Pointer to LIS3MDL_MAG_BLE_t
* Output         : Status of BLE see LIS3MDL_MAG_BLE_t
* Return         : Status [LIS3MDL_ERROR, LIS3MDL_SUCCESS]
*******************************************************************************/

lis3mdl_status_t LIS3MDL_MAG_R_LittleBigEndianInversion(ATMO_DriverInstanceHandle_t i2cInstance, uint8_t i2cAddr, LIS3MDL_MAG_BLE_t *value)
{
 if( !LIS3MDL_MAG_ReadReg(i2cInstance, i2cAddr, LIS3MDL_MAG_CTRL_REG4, (u8_t *)value) )
    return LIS3MDL_ERROR;

  *(int*)value &= LIS3MDL_MAG_BLE_MASK; //mask

  return LIS3MDL_SUCCESS;
}
/*******************************************************************************
* Function Name  : LIS3MDL_MAG_W_OperatingModeZ
* Description    : Write OMZ
* Input          : LIS3MDL_MAG_OMZ_t
* Output         : None
* Return         : Status [LIS3MDL_ERROR, LIS3MDL_SUCCESS]
*******************************************************************************/
lis3mdl_status_t  LIS3MDL_MAG_W_OperatingModeZ(ATMO_DriverInstanceHandle_t i2cInstance, uint8_t i2cAddr, LIS3MDL_MAG_OMZ_t newValue)
{
  u8_t value;

  if( !LIS3MDL_MAG_ReadReg(i2cInstance, i2cAddr, LIS3MDL_MAG_CTRL_REG4, &value) )
    return LIS3MDL_ERROR;

  value &= ~LIS3MDL_MAG_OMZ_MASK; 
  value |= newValue;
  
  if( !LIS3MDL_MAG_WriteReg(i2cInstance, i2cAddr, LIS3MDL_MAG_CTRL_REG4, value) )
    return LIS3MDL_ERROR;

  return LIS3MDL_SUCCESS;
}

/*******************************************************************************
* Function Name  : LIS3MDL_MAG_R_OperatingModeZ
* Description    : Read OMZ
* Input          : Pointer to LIS3MDL_MAG_OMZ_t
* Output         : Status of OMZ see LIS3MDL_MAG_OMZ_t
* Return         : Status [LIS3MDL_ERROR, LIS3MDL_SUCCESS]
*******************************************************************************/

lis3mdl_status_t LIS3MDL_MAG_R_OperatingModeZ(ATMO_DriverInstanceHandle_t i2cInstance, uint8_t i2cAddr, LIS3MDL_MAG_OMZ_t *value)
{
 if( !LIS3MDL_MAG_ReadReg(i2cInstance, i2cAddr, LIS3MDL_MAG_CTRL_REG4, (u8_t *)value) )
    return LIS3MDL_ERROR;

  *(int*)value &= LIS3MDL_MAG_OMZ_MASK; //mask

  return LIS3MDL_SUCCESS;
}
/*******************************************************************************
* Function Name  : LIS3MDL_MAG_W_BlockDataUpdate
* Description    : Write BDU
* Input          : LIS3MDL_MAG_BDU_t
* Output         : None
* Return         : Status [LIS3MDL_ERROR, LIS3MDL_SUCCESS]
*******************************************************************************/
lis3mdl_status_t  LIS3MDL_MAG_W_BlockDataUpdate(ATMO_DriverInstanceHandle_t i2cInstance, uint8_t i2cAddr, LIS3MDL_MAG_BDU_t newValue)
{
  u8_t value;

  if( !LIS3MDL_MAG_ReadReg(i2cInstance, i2cAddr, LIS3MDL_MAG_CTRL_REG5, &value) )
    return LIS3MDL_ERROR;

  value &= ~LIS3MDL_MAG_BDU_MASK; 
  value |= newValue;
  
  if( !LIS3MDL_MAG_WriteReg(i2cInstance, i2cAddr, LIS3MDL_MAG_CTRL_REG5, value) )
    return LIS3MDL_ERROR;

  return LIS3MDL_SUCCESS;
}

/*******************************************************************************
* Function Name  : LIS3MDL_MAG_R_BlockDataUpdate
* Description    : Read BDU
* Input          : Pointer to LIS3MDL_MAG_BDU_t
* Output         : Status of BDU see LIS3MDL_MAG_BDU_t
* Return         : Status [LIS3MDL_ERROR, LIS3MDL_SUCCESS]
*******************************************************************************/

lis3mdl_status_t LIS3MDL_MAG_R_BlockDataUpdate(ATMO_DriverInstanceHandle_t i2cInstance, uint8_t i2cAddr, LIS3MDL_MAG_BDU_t *value)
{
 if( !LIS3MDL_MAG_ReadReg(i2cInstance, i2cAddr, LIS3MDL_MAG_CTRL_REG5, (u8_t *)value) )
    return LIS3MDL_ERROR;

  *(int*)value &= LIS3MDL_MAG_BDU_MASK; //mask

  return LIS3MDL_SUCCESS;
}
/*******************************************************************************
* Function Name  : LIS3MDL_MAG_R_NewXData
* Description    : Read XDA
* Input          : Pointer to LIS3MDL_MAG_XDA_t
* Output         : Status of XDA see LIS3MDL_MAG_XDA_t
* Return         : Status [LIS3MDL_ERROR, LIS3MDL_SUCCESS]
*******************************************************************************/

lis3mdl_status_t LIS3MDL_MAG_R_NewXData(ATMO_DriverInstanceHandle_t i2cInstance, uint8_t i2cAddr, LIS3MDL_MAG_XDA_t *value)
{
 if( !LIS3MDL_MAG_ReadReg(i2cInstance, i2cAddr, LIS3MDL_MAG_STATUS_REG, (u8_t *)value) )
    return LIS3MDL_ERROR;

  *(int*)value &= LIS3MDL_MAG_XDA_MASK; //mask

  return LIS3MDL_SUCCESS;
}
/*******************************************************************************
* Function Name  : LIS3MDL_MAG_R_NewYData
* Description    : Read YDA
* Input          : Pointer to LIS3MDL_MAG_YDA_t
* Output         : Status of YDA see LIS3MDL_MAG_YDA_t
* Return         : Status [LIS3MDL_ERROR, LIS3MDL_SUCCESS]
*******************************************************************************/

lis3mdl_status_t LIS3MDL_MAG_R_NewYData(ATMO_DriverInstanceHandle_t i2cInstance, uint8_t i2cAddr, LIS3MDL_MAG_YDA_t *value)
{
 if( !LIS3MDL_MAG_ReadReg(i2cInstance, i2cAddr, LIS3MDL_MAG_STATUS_REG, (u8_t *)value) )
    return LIS3MDL_ERROR;

  *(int*)value &= LIS3MDL_MAG_YDA_MASK; //mask

  return LIS3MDL_SUCCESS;
}
/*******************************************************************************
* Function Name  : LIS3MDL_MAG_R_NewZData
* Description    : Read ZDA
* Input          : Pointer to LIS3MDL_MAG_ZDA_t
* Output         : Status of ZDA see LIS3MDL_MAG_ZDA_t
* Return         : Status [LIS3MDL_ERROR, LIS3MDL_SUCCESS]
*******************************************************************************/

lis3mdl_status_t LIS3MDL_MAG_R_NewZData(ATMO_DriverInstanceHandle_t i2cInstance, uint8_t i2cAddr, LIS3MDL_MAG_ZDA_t *value)
{
 if( !LIS3MDL_MAG_ReadReg(i2cInstance, i2cAddr, LIS3MDL_MAG_STATUS_REG, (u8_t *)value) )
    return LIS3MDL_ERROR;

  *(int*)value &= LIS3MDL_MAG_ZDA_MASK; //mask

  return LIS3MDL_SUCCESS;
}
/*******************************************************************************
* Function Name  : LIS3MDL_MAG_R_NewXYZData
* Description    : Read ZYXDA
* Input          : Pointer to LIS3MDL_MAG_ZYXDA_t
* Output         : Status of ZYXDA see LIS3MDL_MAG_ZYXDA_t
* Return         : Status [LIS3MDL_ERROR, LIS3MDL_SUCCESS]
*******************************************************************************/

lis3mdl_status_t LIS3MDL_MAG_R_NewXYZData(ATMO_DriverInstanceHandle_t i2cInstance, uint8_t i2cAddr, LIS3MDL_MAG_ZYXDA_t *value)
{
 if( !LIS3MDL_MAG_ReadReg(i2cInstance, i2cAddr, LIS3MDL_MAG_STATUS_REG, (u8_t *)value) )
    return LIS3MDL_ERROR;

  *(int*)value &= LIS3MDL_MAG_ZYXDA_MASK; //mask

  return LIS3MDL_SUCCESS;
}
/*******************************************************************************
* Function Name  : LIS3MDL_MAG_R_DataXOverrun
* Description    : Read XOR
* Input          : Pointer to LIS3MDL_MAG_XOR_t
* Output         : Status of XOR see LIS3MDL_MAG_XOR_t
* Return         : Status [LIS3MDL_ERROR, LIS3MDL_SUCCESS]
*******************************************************************************/

lis3mdl_status_t LIS3MDL_MAG_R_DataXOverrun(ATMO_DriverInstanceHandle_t i2cInstance, uint8_t i2cAddr, LIS3MDL_MAG_XOR_t *value)
{
 if( !LIS3MDL_MAG_ReadReg(i2cInstance, i2cAddr, LIS3MDL_MAG_STATUS_REG, (u8_t *)value) )
    return LIS3MDL_ERROR;

  *(int*)value &= LIS3MDL_MAG_XOR_MASK; //mask

  return LIS3MDL_SUCCESS;
}
/*******************************************************************************
* Function Name  : LIS3MDL_MAG_R_DataYOverrun
* Description    : Read YOR
* Input          : Pointer to LIS3MDL_MAG_YOR_t
* Output         : Status of YOR see LIS3MDL_MAG_YOR_t
* Return         : Status [LIS3MDL_ERROR, LIS3MDL_SUCCESS]
*******************************************************************************/

lis3mdl_status_t LIS3MDL_MAG_R_DataYOverrun(ATMO_DriverInstanceHandle_t i2cInstance, uint8_t i2cAddr, LIS3MDL_MAG_YOR_t *value)
{
 if( !LIS3MDL_MAG_ReadReg(i2cInstance, i2cAddr, LIS3MDL_MAG_STATUS_REG, (u8_t *)value) )
    return LIS3MDL_ERROR;

  *(int*)value &= LIS3MDL_MAG_YOR_MASK; //mask

  return LIS3MDL_SUCCESS;
}
/*******************************************************************************
* Function Name  : LIS3MDL_MAG_R_DataZOverrun
* Description    : Read ZOR
* Input          : Pointer to LIS3MDL_MAG_ZOR_t
* Output         : Status of ZOR see LIS3MDL_MAG_ZOR_t
* Return         : Status [LIS3MDL_ERROR, LIS3MDL_SUCCESS]
*******************************************************************************/

lis3mdl_status_t LIS3MDL_MAG_R_DataZOverrun(ATMO_DriverInstanceHandle_t i2cInstance, uint8_t i2cAddr, LIS3MDL_MAG_ZOR_t *value)
{
 if( !LIS3MDL_MAG_ReadReg(i2cInstance, i2cAddr, LIS3MDL_MAG_STATUS_REG, (u8_t *)value) )
    return LIS3MDL_ERROR;

  *(int*)value &= LIS3MDL_MAG_ZOR_MASK; //mask

  return LIS3MDL_SUCCESS;
}
/*******************************************************************************
* Function Name  : LIS3MDL_MAG_R_DataXYZOverrun
* Description    : Read ZYXOR
* Input          : Pointer to LIS3MDL_MAG_ZYXOR_t
* Output         : Status of ZYXOR see LIS3MDL_MAG_ZYXOR_t
* Return         : Status [LIS3MDL_ERROR, LIS3MDL_SUCCESS]
*******************************************************************************/

lis3mdl_status_t LIS3MDL_MAG_R_DataXYZOverrun(ATMO_DriverInstanceHandle_t i2cInstance, uint8_t i2cAddr, LIS3MDL_MAG_ZYXOR_t *value)
{
 if( !LIS3MDL_MAG_ReadReg(i2cInstance, i2cAddr, LIS3MDL_MAG_STATUS_REG, (u8_t *)value) )
    return LIS3MDL_ERROR;

  *(int*)value &= LIS3MDL_MAG_ZYXOR_MASK; //mask

  return LIS3MDL_SUCCESS;
}
/*******************************************************************************
* Function Name  : LIS3MDL_MAG_W_InterruptEnable
* Description    : Write IEN
* Input          : LIS3MDL_MAG_IEN_t
* Output         : None
* Return         : Status [LIS3MDL_ERROR, LIS3MDL_SUCCESS]
*******************************************************************************/
lis3mdl_status_t  LIS3MDL_MAG_W_InterruptEnable(ATMO_DriverInstanceHandle_t i2cInstance, uint8_t i2cAddr, LIS3MDL_MAG_IEN_t newValue)
{
  u8_t value;

  if( !LIS3MDL_MAG_ReadReg(i2cInstance, i2cAddr, LIS3MDL_MAG_INT_CFG, &value) )
    return LIS3MDL_ERROR;

  value &= ~LIS3MDL_MAG_IEN_MASK; 
  value |= newValue;
  
  if( !LIS3MDL_MAG_WriteReg(i2cInstance, i2cAddr, LIS3MDL_MAG_INT_CFG, value) )
    return LIS3MDL_ERROR;

  return LIS3MDL_SUCCESS;
}

/*******************************************************************************
* Function Name  : LIS3MDL_MAG_R_InterruptEnable
* Description    : Read IEN
* Input          : Pointer to LIS3MDL_MAG_IEN_t
* Output         : Status of IEN see LIS3MDL_MAG_IEN_t
* Return         : Status [LIS3MDL_ERROR, LIS3MDL_SUCCESS]
*******************************************************************************/

lis3mdl_status_t LIS3MDL_MAG_R_InterruptEnable(ATMO_DriverInstanceHandle_t i2cInstance, uint8_t i2cAddr, LIS3MDL_MAG_IEN_t *value)
{
 if( !LIS3MDL_MAG_ReadReg(i2cInstance, i2cAddr, LIS3MDL_MAG_INT_CFG, (u8_t *)value) )
    return LIS3MDL_ERROR;

  *(int*)value &= LIS3MDL_MAG_IEN_MASK; //mask

  return LIS3MDL_SUCCESS;
}
/*******************************************************************************
* Function Name  : LIS3MDL_MAG_W_LatchInterruptRq
* Description    : Write LIR
* Input          : LIS3MDL_MAG_LIR_t
* Output         : None
* Return         : Status [LIS3MDL_ERROR, LIS3MDL_SUCCESS]
*******************************************************************************/
lis3mdl_status_t  LIS3MDL_MAG_W_LatchInterruptRq(ATMO_DriverInstanceHandle_t i2cInstance, uint8_t i2cAddr, LIS3MDL_MAG_LIR_t newValue)
{
  u8_t value;

  if( !LIS3MDL_MAG_ReadReg(i2cInstance, i2cAddr, LIS3MDL_MAG_INT_CFG, &value) )
    return LIS3MDL_ERROR;

  value &= ~LIS3MDL_MAG_LIR_MASK; 
  value |= newValue;
  
  if( !LIS3MDL_MAG_WriteReg(i2cInstance, i2cAddr, LIS3MDL_MAG_INT_CFG, value) )
    return LIS3MDL_ERROR;

  return LIS3MDL_SUCCESS;
}

/*******************************************************************************
* Function Name  : LIS3MDL_MAG_R_LatchInterruptRq
* Description    : Read LIR
* Input          : Pointer to LIS3MDL_MAG_LIR_t
* Output         : Status of LIR see LIS3MDL_MAG_LIR_t
* Return         : Status [LIS3MDL_ERROR, LIS3MDL_SUCCESS]
*******************************************************************************/

lis3mdl_status_t LIS3MDL_MAG_R_LatchInterruptRq(ATMO_DriverInstanceHandle_t i2cInstance, uint8_t i2cAddr, LIS3MDL_MAG_LIR_t *value)
{
 if( !LIS3MDL_MAG_ReadReg(i2cInstance, i2cAddr, LIS3MDL_MAG_INT_CFG, (u8_t *)value) )
    return LIS3MDL_ERROR;

  *(int*)value &= LIS3MDL_MAG_LIR_MASK; //mask

  return LIS3MDL_SUCCESS;
}
/*******************************************************************************
* Function Name  : LIS3MDL_MAG_W_InterruptActive
* Description    : Write IEA
* Input          : LIS3MDL_MAG_IEA_t
* Output         : None
* Return         : Status [LIS3MDL_ERROR, LIS3MDL_SUCCESS]
*******************************************************************************/
lis3mdl_status_t  LIS3MDL_MAG_W_InterruptActive(ATMO_DriverInstanceHandle_t i2cInstance, uint8_t i2cAddr, LIS3MDL_MAG_IEA_t newValue)
{
  u8_t value;

  if( !LIS3MDL_MAG_ReadReg(i2cInstance, i2cAddr, LIS3MDL_MAG_INT_CFG, &value) )
    return LIS3MDL_ERROR;

  value &= ~LIS3MDL_MAG_IEA_MASK; 
  value |= newValue;
  
  if( !LIS3MDL_MAG_WriteReg(i2cInstance, i2cAddr, LIS3MDL_MAG_INT_CFG, value) )
    return LIS3MDL_ERROR;

  return LIS3MDL_SUCCESS;
}

/*******************************************************************************
* Function Name  : LIS3MDL_MAG_R_InterruptActive
* Description    : Read IEA
* Input          : Pointer to LIS3MDL_MAG_IEA_t
* Output         : Status of IEA see LIS3MDL_MAG_IEA_t
* Return         : Status [LIS3MDL_ERROR, LIS3MDL_SUCCESS]
*******************************************************************************/

lis3mdl_status_t LIS3MDL_MAG_R_InterruptActive(ATMO_DriverInstanceHandle_t i2cInstance, uint8_t i2cAddr, LIS3MDL_MAG_IEA_t *value)
{
 if( !LIS3MDL_MAG_ReadReg(i2cInstance, i2cAddr, LIS3MDL_MAG_INT_CFG, (u8_t *)value) )
    return LIS3MDL_ERROR;

  *(int*)value &= LIS3MDL_MAG_IEA_MASK; //mask

  return LIS3MDL_SUCCESS;
}
/*******************************************************************************
* Function Name  : LIS3MDL_MAG_W_InterruptOnZ
* Description    : Write ZIEN
* Input          : LIS3MDL_MAG_ZIEN_t
* Output         : None
* Return         : Status [LIS3MDL_ERROR, LIS3MDL_SUCCESS]
*******************************************************************************/
lis3mdl_status_t  LIS3MDL_MAG_W_InterruptOnZ(ATMO_DriverInstanceHandle_t i2cInstance, uint8_t i2cAddr, LIS3MDL_MAG_ZIEN_t newValue)
{
  u8_t value;

  if( !LIS3MDL_MAG_ReadReg(i2cInstance, i2cAddr, LIS3MDL_MAG_INT_CFG, &value) )
    return LIS3MDL_ERROR;

  value &= ~LIS3MDL_MAG_ZIEN_MASK; 
  value |= newValue;
  
  if( !LIS3MDL_MAG_WriteReg(i2cInstance, i2cAddr, LIS3MDL_MAG_INT_CFG, value) )
    return LIS3MDL_ERROR;

  return LIS3MDL_SUCCESS;
}

/*******************************************************************************
* Function Name  : LIS3MDL_MAG_R_InterruptOnZ
* Description    : Read ZIEN
* Input          : Pointer to LIS3MDL_MAG_ZIEN_t
* Output         : Status of ZIEN see LIS3MDL_MAG_ZIEN_t
* Return         : Status [LIS3MDL_ERROR, LIS3MDL_SUCCESS]
*******************************************************************************/

lis3mdl_status_t LIS3MDL_MAG_R_InterruptOnZ(ATMO_DriverInstanceHandle_t i2cInstance, uint8_t i2cAddr, LIS3MDL_MAG_ZIEN_t *value)
{
 if( !LIS3MDL_MAG_ReadReg(i2cInstance, i2cAddr, LIS3MDL_MAG_INT_CFG, (u8_t *)value) )
    return LIS3MDL_ERROR;

  *(int*)value &= LIS3MDL_MAG_ZIEN_MASK; //mask

  return LIS3MDL_SUCCESS;
}
/*******************************************************************************
* Function Name  : LIS3MDL_MAG_W_InterruptOnY
* Description    : Write YIEN
* Input          : LIS3MDL_MAG_YIEN_t
* Output         : None
* Return         : Status [LIS3MDL_ERROR, LIS3MDL_SUCCESS]
*******************************************************************************/
lis3mdl_status_t  LIS3MDL_MAG_W_InterruptOnY(ATMO_DriverInstanceHandle_t i2cInstance, uint8_t i2cAddr, LIS3MDL_MAG_YIEN_t newValue)
{
  u8_t value;

  if( !LIS3MDL_MAG_ReadReg(i2cInstance, i2cAddr, LIS3MDL_MAG_INT_CFG, &value) )
    return LIS3MDL_ERROR;

  value &= ~LIS3MDL_MAG_YIEN_MASK; 
  value |= newValue;
  
  if( !LIS3MDL_MAG_WriteReg(i2cInstance, i2cAddr, LIS3MDL_MAG_INT_CFG, value) )
    return LIS3MDL_ERROR;

  return LIS3MDL_SUCCESS;
}

/*******************************************************************************
* Function Name  : LIS3MDL_MAG_R_InterruptOnY
* Description    : Read YIEN
* Input          : Pointer to LIS3MDL_MAG_YIEN_t
* Output         : Status of YIEN see LIS3MDL_MAG_YIEN_t
* Return         : Status [LIS3MDL_ERROR, LIS3MDL_SUCCESS]
*******************************************************************************/

lis3mdl_status_t LIS3MDL_MAG_R_InterruptOnY(ATMO_DriverInstanceHandle_t i2cInstance, uint8_t i2cAddr, LIS3MDL_MAG_YIEN_t *value)
{
 if( !LIS3MDL_MAG_ReadReg(i2cInstance, i2cAddr, LIS3MDL_MAG_INT_CFG, (u8_t *)value) )
    return LIS3MDL_ERROR;

  *(int*)value &= LIS3MDL_MAG_YIEN_MASK; //mask

  return LIS3MDL_SUCCESS;
}
/*******************************************************************************
* Function Name  : LIS3MDL_MAG_W_InterruptOnX
* Description    : Write XIEN
* Input          : LIS3MDL_MAG_XIEN_t
* Output         : None
* Return         : Status [LIS3MDL_ERROR, LIS3MDL_SUCCESS]
*******************************************************************************/
lis3mdl_status_t  LIS3MDL_MAG_W_InterruptOnX(ATMO_DriverInstanceHandle_t i2cInstance, uint8_t i2cAddr, LIS3MDL_MAG_XIEN_t newValue)
{
  u8_t value;

  if( !LIS3MDL_MAG_ReadReg(i2cInstance, i2cAddr, LIS3MDL_MAG_INT_CFG, &value) )
    return LIS3MDL_ERROR;

  value &= ~LIS3MDL_MAG_XIEN_MASK; 
  value |= newValue;
  
  if( !LIS3MDL_MAG_WriteReg(i2cInstance, i2cAddr, LIS3MDL_MAG_INT_CFG, value) )
    return LIS3MDL_ERROR;

  return LIS3MDL_SUCCESS;
}

/*******************************************************************************
* Function Name  : LIS3MDL_MAG_R_InterruptOnX
* Description    : Read XIEN
* Input          : Pointer to LIS3MDL_MAG_XIEN_t
* Output         : Status of XIEN see LIS3MDL_MAG_XIEN_t
* Return         : Status [LIS3MDL_ERROR, LIS3MDL_SUCCESS]
*******************************************************************************/

lis3mdl_status_t LIS3MDL_MAG_R_InterruptOnX(ATMO_DriverInstanceHandle_t i2cInstance, uint8_t i2cAddr, LIS3MDL_MAG_XIEN_t *value)
{
 if( !LIS3MDL_MAG_ReadReg(i2cInstance, i2cAddr, LIS3MDL_MAG_INT_CFG, (u8_t *)value) )
    return LIS3MDL_ERROR;

  *(int*)value &= LIS3MDL_MAG_XIEN_MASK; //mask

  return LIS3MDL_SUCCESS;
}
/*******************************************************************************
* Function Name  : LIS3MDL_MAG_W_InterruptFlag
* Description    : Write INT
* Input          : LIS3MDL_MAG_INT_t
* Output         : None
* Return         : Status [LIS3MDL_ERROR, LIS3MDL_SUCCESS]
*******************************************************************************/
lis3mdl_status_t  LIS3MDL_MAG_W_InterruptFlag(ATMO_DriverInstanceHandle_t i2cInstance, uint8_t i2cAddr, LIS3MDL_MAG_INT_t newValue)
{
  u8_t value;

  if( !LIS3MDL_MAG_ReadReg(i2cInstance, i2cAddr, LIS3MDL_MAG_INT_SRC, &value) )
    return LIS3MDL_ERROR;

  value &= ~LIS3MDL_MAG_INT_MASK; 
  value |= newValue;
  
  if( !LIS3MDL_MAG_WriteReg(i2cInstance, i2cAddr, LIS3MDL_MAG_INT_SRC, value) )
    return LIS3MDL_ERROR;

  return LIS3MDL_SUCCESS;
}

/*******************************************************************************
* Function Name  : LIS3MDL_MAG_R_InterruptFlag
* Description    : Read INT
* Input          : Pointer to LIS3MDL_MAG_INT_t
* Output         : Status of INT see LIS3MDL_MAG_INT_t
* Return         : Status [LIS3MDL_ERROR, LIS3MDL_SUCCESS]
*******************************************************************************/

lis3mdl_status_t LIS3MDL_MAG_R_InterruptFlag(ATMO_DriverInstanceHandle_t i2cInstance, uint8_t i2cAddr, LIS3MDL_MAG_INT_t *value)
{
 if( !LIS3MDL_MAG_ReadReg(i2cInstance, i2cAddr, LIS3MDL_MAG_INT_SRC, (u8_t *)value) )
    return LIS3MDL_ERROR;

  *(int*)value &= LIS3MDL_MAG_INT_MASK; //mask

  return LIS3MDL_SUCCESS;
}
/*******************************************************************************
* Function Name  : LIS3MDL_MAG_W_MagneticFieldOverflow
* Description    : Write MROI
* Input          : LIS3MDL_MAG_MROI_t
* Output         : None
* Return         : Status [LIS3MDL_ERROR, LIS3MDL_SUCCESS]
*******************************************************************************/
lis3mdl_status_t  LIS3MDL_MAG_W_MagneticFieldOverflow(ATMO_DriverInstanceHandle_t i2cInstance, uint8_t i2cAddr, LIS3MDL_MAG_MROI_t newValue)
{
  u8_t value;

  if( !LIS3MDL_MAG_ReadReg(i2cInstance, i2cAddr, LIS3MDL_MAG_INT_SRC, &value) )
    return LIS3MDL_ERROR;

  value &= ~LIS3MDL_MAG_MROI_MASK; 
  value |= newValue;
  
  if( !LIS3MDL_MAG_WriteReg(i2cInstance, i2cAddr, LIS3MDL_MAG_INT_SRC, value) )
    return LIS3MDL_ERROR;

  return LIS3MDL_SUCCESS;
}

/*******************************************************************************
* Function Name  : LIS3MDL_MAG_R_MagneticFieldOverflow
* Description    : Read MROI
* Input          : Pointer to LIS3MDL_MAG_MROI_t
* Output         : Status of MROI see LIS3MDL_MAG_MROI_t
* Return         : Status [LIS3MDL_ERROR, LIS3MDL_SUCCESS]
*******************************************************************************/

lis3mdl_status_t LIS3MDL_MAG_R_MagneticFieldOverflow(ATMO_DriverInstanceHandle_t i2cInstance, uint8_t i2cAddr, LIS3MDL_MAG_MROI_t *value)
{
 if( !LIS3MDL_MAG_ReadReg(i2cInstance, i2cAddr, LIS3MDL_MAG_INT_SRC, (u8_t *)value) )
    return LIS3MDL_ERROR;

  *(int*)value &= LIS3MDL_MAG_MROI_MASK; //mask

  return LIS3MDL_SUCCESS;
}
/*******************************************************************************
* Function Name  : LIS3MDL_MAG_W_NegativeThresholdFlagZ
* Description    : Write NTH_Z
* Input          : LIS3MDL_MAG_NTH_Z_t
* Output         : None
* Return         : Status [LIS3MDL_ERROR, LIS3MDL_SUCCESS]
*******************************************************************************/
lis3mdl_status_t  LIS3MDL_MAG_W_NegativeThresholdFlagZ(ATMO_DriverInstanceHandle_t i2cInstance, uint8_t i2cAddr, LIS3MDL_MAG_NTH_Z_t newValue)
{
  u8_t value;

  if( !LIS3MDL_MAG_ReadReg(i2cInstance, i2cAddr, LIS3MDL_MAG_INT_SRC, &value) )
    return LIS3MDL_ERROR;

  value &= ~LIS3MDL_MAG_NTH_Z_MASK; 
  value |= newValue;
  
  if( !LIS3MDL_MAG_WriteReg(i2cInstance, i2cAddr, LIS3MDL_MAG_INT_SRC, value) )
    return LIS3MDL_ERROR;

  return LIS3MDL_SUCCESS;
}

/*******************************************************************************
* Function Name  : LIS3MDL_MAG_R_NegativeThresholdFlagZ
* Description    : Read NTH_Z
* Input          : Pointer to LIS3MDL_MAG_NTH_Z_t
* Output         : Status of NTH_Z see LIS3MDL_MAG_NTH_Z_t
* Return         : Status [LIS3MDL_ERROR, LIS3MDL_SUCCESS]
*******************************************************************************/

lis3mdl_status_t LIS3MDL_MAG_R_NegativeThresholdFlagZ(ATMO_DriverInstanceHandle_t i2cInstance, uint8_t i2cAddr, LIS3MDL_MAG_NTH_Z_t *value)
{
 if( !LIS3MDL_MAG_ReadReg(i2cInstance, i2cAddr, LIS3MDL_MAG_INT_SRC, (u8_t *)value) )
    return LIS3MDL_ERROR;

  *(int*)value &= LIS3MDL_MAG_NTH_Z_MASK; //mask

  return LIS3MDL_SUCCESS;
}
/*******************************************************************************
* Function Name  : LIS3MDL_MAG_W_NegativeThresholdFlagY
* Description    : Write NTH_Y
* Input          : LIS3MDL_MAG_NTH_Y_t
* Output         : None
* Return         : Status [LIS3MDL_ERROR, LIS3MDL_SUCCESS]
*******************************************************************************/
lis3mdl_status_t  LIS3MDL_MAG_W_NegativeThresholdFlagY(ATMO_DriverInstanceHandle_t i2cInstance, uint8_t i2cAddr, LIS3MDL_MAG_NTH_Y_t newValue)
{
  u8_t value;

  if( !LIS3MDL_MAG_ReadReg(i2cInstance, i2cAddr, LIS3MDL_MAG_INT_SRC, &value) )
    return LIS3MDL_ERROR;

  value &= ~LIS3MDL_MAG_NTH_Y_MASK; 
  value |= newValue;
  
  if( !LIS3MDL_MAG_WriteReg(i2cInstance, i2cAddr, LIS3MDL_MAG_INT_SRC, value) )
    return LIS3MDL_ERROR;

  return LIS3MDL_SUCCESS;
}

/*******************************************************************************
* Function Name  : LIS3MDL_MAG_R_NegativeThresholdFlagY
* Description    : Read NTH_Y
* Input          : Pointer to LIS3MDL_MAG_NTH_Y_t
* Output         : Status of NTH_Y see LIS3MDL_MAG_NTH_Y_t
* Return         : Status [LIS3MDL_ERROR, LIS3MDL_SUCCESS]
*******************************************************************************/

lis3mdl_status_t LIS3MDL_MAG_R_NegativeThresholdFlagY(ATMO_DriverInstanceHandle_t i2cInstance, uint8_t i2cAddr, LIS3MDL_MAG_NTH_Y_t *value)
{
 if( !LIS3MDL_MAG_ReadReg(i2cInstance, i2cAddr, LIS3MDL_MAG_INT_SRC, (u8_t *)value) )
    return LIS3MDL_ERROR;

  *(int*)value &= LIS3MDL_MAG_NTH_Y_MASK; //mask

  return LIS3MDL_SUCCESS;
}
/*******************************************************************************
* Function Name  : LIS3MDL_MAG_W_NegativeThresholdFlagX
* Description    : Write NTH_X
* Input          : LIS3MDL_MAG_NTH_X_t
* Output         : None
* Return         : Status [LIS3MDL_ERROR, LIS3MDL_SUCCESS]
*******************************************************************************/
lis3mdl_status_t  LIS3MDL_MAG_W_NegativeThresholdFlagX(ATMO_DriverInstanceHandle_t i2cInstance, uint8_t i2cAddr, LIS3MDL_MAG_NTH_X_t newValue)
{
  u8_t value;

  if( !LIS3MDL_MAG_ReadReg(i2cInstance, i2cAddr, LIS3MDL_MAG_INT_SRC, &value) )
    return LIS3MDL_ERROR;

  value &= ~LIS3MDL_MAG_NTH_X_MASK; 
  value |= newValue;
  
  if( !LIS3MDL_MAG_WriteReg(i2cInstance, i2cAddr, LIS3MDL_MAG_INT_SRC, value) )
    return LIS3MDL_ERROR;

  return LIS3MDL_SUCCESS;
}

/*******************************************************************************
* Function Name  : LIS3MDL_MAG_R_NegativeThresholdFlagX
* Description    : Read NTH_X
* Input          : Pointer to LIS3MDL_MAG_NTH_X_t
* Output         : Status of NTH_X see LIS3MDL_MAG_NTH_X_t
* Return         : Status [LIS3MDL_ERROR, LIS3MDL_SUCCESS]
*******************************************************************************/

lis3mdl_status_t LIS3MDL_MAG_R_NegativeThresholdFlagX(ATMO_DriverInstanceHandle_t i2cInstance, uint8_t i2cAddr, LIS3MDL_MAG_NTH_X_t *value)
{
 if( !LIS3MDL_MAG_ReadReg(i2cInstance, i2cAddr, LIS3MDL_MAG_INT_SRC, (u8_t *)value) )
    return LIS3MDL_ERROR;

  *(int*)value &= LIS3MDL_MAG_NTH_X_MASK; //mask

  return LIS3MDL_SUCCESS;
}
/*******************************************************************************
* Function Name  : LIS3MDL_MAG_W_PositiveThresholdFlagZ
* Description    : Write PTH_Z
* Input          : LIS3MDL_MAG_PTH_Z_t
* Output         : None
* Return         : Status [LIS3MDL_ERROR, LIS3MDL_SUCCESS]
*******************************************************************************/
lis3mdl_status_t  LIS3MDL_MAG_W_PositiveThresholdFlagZ(ATMO_DriverInstanceHandle_t i2cInstance, uint8_t i2cAddr, LIS3MDL_MAG_PTH_Z_t newValue)
{
  u8_t value;

  if( !LIS3MDL_MAG_ReadReg(i2cInstance, i2cAddr, LIS3MDL_MAG_INT_SRC, &value) )
    return LIS3MDL_ERROR;

  value &= ~LIS3MDL_MAG_PTH_Z_MASK; 
  value |= newValue;
  
  if( !LIS3MDL_MAG_WriteReg(i2cInstance, i2cAddr, LIS3MDL_MAG_INT_SRC, value) )
    return LIS3MDL_ERROR;

  return LIS3MDL_SUCCESS;
}

/*******************************************************************************
* Function Name  : LIS3MDL_MAG_R_PositiveThresholdFlagZ
* Description    : Read PTH_Z
* Input          : Pointer to LIS3MDL_MAG_PTH_Z_t
* Output         : Status of PTH_Z see LIS3MDL_MAG_PTH_Z_t
* Return         : Status [LIS3MDL_ERROR, LIS3MDL_SUCCESS]
*******************************************************************************/

lis3mdl_status_t LIS3MDL_MAG_R_PositiveThresholdFlagZ(ATMO_DriverInstanceHandle_t i2cInstance, uint8_t i2cAddr, LIS3MDL_MAG_PTH_Z_t *value)
{
 if( !LIS3MDL_MAG_ReadReg(i2cInstance, i2cAddr, LIS3MDL_MAG_INT_SRC, (u8_t *)value) )
    return LIS3MDL_ERROR;

  *(int*)value &= LIS3MDL_MAG_PTH_Z_MASK; //mask

  return LIS3MDL_SUCCESS;
}
/*******************************************************************************
* Function Name  : LIS3MDL_MAG_W_PositiveThresholdFlagY
* Description    : Write PTH_Y
* Input          : LIS3MDL_MAG_PTH_Y_t
* Output         : None
* Return         : Status [LIS3MDL_ERROR, LIS3MDL_SUCCESS]
*******************************************************************************/
lis3mdl_status_t  LIS3MDL_MAG_W_PositiveThresholdFlagY(ATMO_DriverInstanceHandle_t i2cInstance, uint8_t i2cAddr, LIS3MDL_MAG_PTH_Y_t newValue)
{
  u8_t value;

  if( !LIS3MDL_MAG_ReadReg(i2cInstance, i2cAddr, LIS3MDL_MAG_INT_SRC, &value) )
    return LIS3MDL_ERROR;

  value &= ~LIS3MDL_MAG_PTH_Y_MASK; 
  value |= newValue;
  
  if( !LIS3MDL_MAG_WriteReg(i2cInstance, i2cAddr, LIS3MDL_MAG_INT_SRC, value) )
    return LIS3MDL_ERROR;

  return LIS3MDL_SUCCESS;
}

/*******************************************************************************
* Function Name  : LIS3MDL_MAG_R_PositiveThresholdFlagY
* Description    : Read PTH_Y
* Input          : Pointer to LIS3MDL_MAG_PTH_Y_t
* Output         : Status of PTH_Y see LIS3MDL_MAG_PTH_Y_t
* Return         : Status [LIS3MDL_ERROR, LIS3MDL_SUCCESS]
*******************************************************************************/

lis3mdl_status_t LIS3MDL_MAG_R_PositiveThresholdFlagY(ATMO_DriverInstanceHandle_t i2cInstance, uint8_t i2cAddr, LIS3MDL_MAG_PTH_Y_t *value)
{
 if( !LIS3MDL_MAG_ReadReg(i2cInstance, i2cAddr, LIS3MDL_MAG_INT_SRC, (u8_t *)value) )
    return LIS3MDL_ERROR;

  *(int*)value &= LIS3MDL_MAG_PTH_Y_MASK; //mask

  return LIS3MDL_SUCCESS;
}
/*******************************************************************************
* Function Name  : LIS3MDL_MAG_W_PositiveThresholdFlagX
* Description    : Write PTH_X
* Input          : LIS3MDL_MAG_PTH_X_t
* Output         : None
* Return         : Status [LIS3MDL_ERROR, LIS3MDL_SUCCESS]
*******************************************************************************/
lis3mdl_status_t  LIS3MDL_MAG_W_PositiveThresholdFlagX(ATMO_DriverInstanceHandle_t i2cInstance, uint8_t i2cAddr, LIS3MDL_MAG_PTH_X_t newValue)
{
  u8_t value;

  if( !LIS3MDL_MAG_ReadReg(i2cInstance, i2cAddr, LIS3MDL_MAG_INT_SRC, &value) )
    return LIS3MDL_ERROR;

  value &= ~LIS3MDL_MAG_PTH_X_MASK; 
  value |= newValue;
  
  if( !LIS3MDL_MAG_WriteReg(i2cInstance, i2cAddr, LIS3MDL_MAG_INT_SRC, value) )
    return LIS3MDL_ERROR;

  return LIS3MDL_SUCCESS;
}

/*******************************************************************************
* Function Name  : LIS3MDL_MAG_R_PositiveThresholdFlagX
* Description    : Read PTH_X
* Input          : Pointer to LIS3MDL_MAG_PTH_X_t
* Output         : Status of PTH_X see LIS3MDL_MAG_PTH_X_t
* Return         : Status [LIS3MDL_ERROR, LIS3MDL_SUCCESS]
*******************************************************************************/

lis3mdl_status_t LIS3MDL_MAG_R_PositiveThresholdFlagX(ATMO_DriverInstanceHandle_t i2cInstance, uint8_t i2cAddr, LIS3MDL_MAG_PTH_X_t *value)
{
 if( !LIS3MDL_MAG_ReadReg(i2cInstance, i2cAddr, LIS3MDL_MAG_INT_SRC, (u8_t *)value) )
    return LIS3MDL_ERROR;

  *(int*)value &= LIS3MDL_MAG_PTH_X_MASK; //mask

  return LIS3MDL_SUCCESS;
}
/*******************************************************************************
* Function Name  : lis3mdl_status_t LIS3MDL_MAG_Get_Magnetic(u8_t *buff)
* Description    : Read Magnetic output register
* Input          : pointer to [u8_t]
* Output         : Magnetic buffer u8_t
* Return         : Status [LIS3MDL_ERROR, LIS3MDL_SUCCESS]
*******************************************************************************/
lis3mdl_status_t LIS3MDL_MAG_Get_Magnetic(ATMO_DriverInstanceHandle_t i2cInstance, uint8_t i2cAddr, u8_t *buff) 
{
  u8_t i, j, k;
  u8_t numberOfByteForDimension;
  
  numberOfByteForDimension=6/3;

  k=0;
  for (i=0; i<3;i++ ) 
  {
	for (j=0; j<numberOfByteForDimension;j++ )
	{	
		if( !LIS3MDL_MAG_ReadReg(i2cInstance, i2cAddr, LIS3MDL_MAG_OUTX_L+k, &buff[k]))
		  return LIS3MDL_ERROR;
		k++;	
	}
  }

  return LIS3MDL_SUCCESS; 
}

/*******************************************************************************
* Function Name  : lis3mdl_status_t LIS3MDL_MAG_Get_Temperature(u8_t *buff)
* Description    : Read Temperature output register
* Input          : pointer to [u8_t]
* Output         : Temperature buffer u8_t
* Return         : Status [LIS3MDL_ERROR, LIS3MDL_SUCCESS]
*******************************************************************************/
lis3mdl_status_t LIS3MDL_MAG_Get_Temperature(ATMO_DriverInstanceHandle_t i2cInstance, uint8_t i2cAddr, u8_t *buff) 
{
  u8_t i, j, k;
  u8_t numberOfByteForDimension;
  
  numberOfByteForDimension=2/1;

  k=0;
  for (i=0; i<1;i++ ) 
  {
	for (j=0; j<numberOfByteForDimension;j++ )
	{	
		if( !LIS3MDL_MAG_ReadReg(i2cInstance, i2cAddr, LIS3MDL_MAG_TEMP_OUT_L+k, &buff[k]))
		  return LIS3MDL_ERROR;
		k++;	
	}
  }

  return LIS3MDL_SUCCESS; 
}


/*******************************************************************************
* Function Name  : lis3mdl_status_t LIS3MDL_MAG_Set_MagneticThreshold(u8_t *buff) 
* Description    : Set MagneticThreshold data row
* Input          : pointer to [u8_t]
* Output         : None
* Return         : Status [LIS3MDL_ERROR, LIS3MDL_SUCCESS]
*******************************************************************************/
lis3mdl_status_t LIS3MDL_MAG_Set_MagneticThreshold(ATMO_DriverInstanceHandle_t i2cInstance, uint8_t i2cAddr, u8_t *buff) 
{
  u8_t  i;

  for (i=0; i<2;i++ ) 
  {
	if( !LIS3MDL_MAG_WriteReg(i2cInstance, i2cAddr, LIS3MDL_MAG_INT_THS_L+i,  buff[i]) )
		return LIS3MDL_ERROR;
  }
  return LIS3MDL_SUCCESS;  
}

/*******************************************************************************
* Function Name  : lis3mdl_status_t LIS3MDL_MAG_Get_MagneticThreshold(u8_t *buff)
* Description    : Read MagneticThreshold output register
* Input          : pointer to [u8_t]
* Output         : MagneticThreshold buffer u8_t
* Return         : Status [LIS3MDL_ERROR, LIS3MDL_SUCCESS]
*******************************************************************************/
lis3mdl_status_t LIS3MDL_MAG_Get_MagneticThreshold(ATMO_DriverInstanceHandle_t i2cInstance, uint8_t i2cAddr, u8_t *buff) 
{
  u8_t i, j, k;
  u8_t numberOfByteForDimension;
  
  numberOfByteForDimension=2/1;

  k=0;
  for (i=0; i<1;i++ ) 
  {
	for (j=0; j<numberOfByteForDimension;j++ )
	{	
		if( !LIS3MDL_MAG_ReadReg(i2cInstance, i2cAddr, LIS3MDL_MAG_INT_THS_L+k, &buff[k]))
		  return LIS3MDL_ERROR;
		k++;	
	}
  }

  return LIS3MDL_SUCCESS; 
}

int16_t LIS3MDL_MAG_Get_MagneticFieldX(ATMO_DriverInstanceHandle_t i2cInstance, uint8_t i2cAddr)
{
	static Type3Axis16bit_U magneticField;
	LIS3MDL_MAG_Get_Magnetic(i2cInstance, i2cAddr, magneticField.u8bit);
	
	return magneticField.i16bit[0];
}

int16_t LIS3MDL_MAG_Get_MagneticFieldY(ATMO_DriverInstanceHandle_t i2cInstance, uint8_t i2cAddr)
{
	static Type3Axis16bit_U magneticField;
	LIS3MDL_MAG_Get_Magnetic(i2cInstance, i2cAddr, magneticField.u8bit);
	
	return magneticField.i16bit[1];
}

int16_t LIS3MDL_MAG_Get_MagneticFieldZ(ATMO_DriverInstanceHandle_t i2cInstance, uint8_t i2cAddr)
{
	static Type3Axis16bit_U magneticField;
	LIS3MDL_MAG_Get_Magnetic(i2cInstance, i2cAddr, magneticField.u8bit);
	
	return magneticField.i16bit[2];
}

